@@ -34,7 +34,7 @@ public:
     void stopRecording();
 
 signals:
-    void updateVuMeterSignal(int volume);
+    void updateVuMeterSignal(float volume);
 
 public slots:
     void processData(const void *data, size_t length);
